@@ -309,15 +309,11 @@ class OpensearchTaskHandler(FileTaskHandler, ExternalLoggingMixin, LoggingMixin)
             data_interval_end = self._clean_date(dag_run.data_interval_end)
             logical_date = self._clean_date(dag_run.logical_date)
         else:
-            if dag_run.data_interval_start:
-                data_interval_start = dag_run.data_interval_start.isoformat()
-            else:
-                data_interval_start = ""
-            if dag_run.data_interval_end:
-                data_interval_end = dag_run.data_interval_end.isoformat()
-            else:
-                data_interval_end = ""
-            logical_date = dag_run.logical_date.isoformat()
+            data_interval_start = (
+                dag_run.data_interval_start.isoformat() if dag_run.data_interval_start else ""
+            )
+            data_interval_end = dag_run.data_interval_end.isoformat() if dag_run.data_interval_end else ""
+            logical_date = dag_run.logical_date.isoformat() if dag_run.logical_date else ""
         return log_id_template.format(
             dag_id=ti.dag_id,
             task_id=ti.task_id,
